import requests
from search_engine_parser import GoogleSearch
import re


class GithubData:
    """
    A class to manage the Github API.
    """

    def __init__(self, title):
        """
        Initialize the Github API.
        """
        print(title)

    def get_github_resources(self, query):
        """
        this function will search github for a query and return a list of links if available,
        if not available it will search google for the query and return a list of links.
        """
        github = {}
        github_repos = self.search_github_repos(query)
        github_links = self.search_github_repos_in_google(query)
        valid_github_links = self.get_valid_urls(github_links)
        github["links"] = valid_github_links
        github["repos"] = self.get_first_ten_repos(github_repos["items"])
        return github

    def get_first_ten_repos(self, repos):
        """
        Get the first ten repos if more than 10 repos are found.
        otherwise return all repos.
        :param repos: The repos.
        """
        if len(repos) > 10:
            return repos[:10]
        else:
            return repos

    def get_user_repos(self, user):
        """
        Get the repos of a user.

        :param user: The Github user.
        :return: The repos of the user.
        """
        url = "https://api.github.com/users/{}/repos".format(user)
        response = requests.get(url)
        response.raise_for_status()
        return response.json()

    def search_github_repos(self, query):
        """
        Search for repos on Github.
        :param query: The search query.
        :return: The repos found.
        """
        url = "https://api.github.com/search/repositories?q={}".format(query)
        response = requests.get(url)
        response.raise_for_status()
        return response.json()

    def search_github_repos_in_google(self, query):
        """
        Search for repos on Github using google search enging.
        :param query: The search query.
        :return: The repos found.
        """
        google_query = "site:github.com {}".format(query)
        search_args = (google_query, 1)
        gsearch = GoogleSearch()
        gresults = gsearch.search(*search_args)
        return gresults["links"]

    def get_valid_urls(self, links):
        """
        filter out invalid urls
        """
        validUrls = []
        for i in links:
            if "github.com" in i:
                uriTrimmed = re.match(r"^.*?\&sa=", i[29:]).group(0)
                ur = uriTrimmed.replace("&sa=", "")
                validUrls.append(ur)
        return validUrls