import React, { useState } from 'react'
import SimilarQuestion from './similar-question'
import { Title } from '../styled-text-spans/index'
import styles from './similar-question-suggestions.module.css'
import useDebounce from '../../hooks/useDebounce'
import { Spinner } from '../icons'
import Axios from 'axios'
import NoResource from '../no-resource/NoResource'

const SimilarQuestionSuggestions = ({ title, description, tags }) => {
  const [isLoading, setIsLoading] = useState(true)
  const [similarQuestions, setSimilarQuestions] = useState([])
  const [error, setError] = useState({
    isError: false,
    message: ''
  })
  const getSimilarQuestions = async () => {
    console.log('getSimilarQuestions')
    const data = { question: title }
    const headers = {
      'Content-Type': 'application/json',
      'Access-Control-Allow-Origin': '*'
    }
    try {
      const response = await Axios.post(
        'https://localhost:3002/',
        data,
        headers
      )
      if (response.status === 200) {
        setSimilarQuestions(response.data)
      } else {
        setError({
          isError: true,
          message:
            'Something went wrong while searching similar questions. Please try again'
        })
      }
    } catch (err) {
      console.log(err)
      setError({
        isError: true,
        message:
          'Similar question finding is not supported in this environment yet. Hopefully it will be available soon.'
      })
    }
    setIsLoading(false)
  }

  useDebounce(
    async () => {
      await getSimilarQuestions()
    },
    1000,
    [title]
  )
  const { isError, message } = error
  return (
    <div className={styles.container}>
      <h1>
        Similar questions -{' '}
        <Title title={title} textColor="var(--main-purple)" />
      </h1>
      {isLoading ? (
        <Spinner className={styles.spinner} />
      ) : isError ? (
        <NoResource message={message} />
      ) : similarQuestions.length > 0 ? (
        similarQuestions.map((question, index) => {
          return <SimilarQuestion question_prop={question} key={index} />
        })
      ) : (
        <NoResource message="No similar questions found for this question. Submit your question to get an answer generated in few seconds" />
      )}
    </div>
  )
}

export default SimilarQuestionSuggestions
