import * as React from 'react'
import Box from '@material-ui/core/Box'
import Stepper from '@material-ui/core/Stepper'
import Step from '@material-ui/core/Step'
import StepLabel from '@material-ui/core/StepLabel'
import StepContent from '@material-ui/core/StepContent'
import Button from '../../button'
import Paper from '@material-ui/core/Paper'
import Typography from '@material-ui/core/Typography'
import { createTheme } from '@material-ui/core'
import { ThemeProvider } from '@material-ui/styles'
import Styles from './TelegramInstructions.module.css'

const theme = createTheme({
  overrides: {
    MuiStepIcon: {
      root: {
        '&$completed': {
          color: 'green'
        },
        '&$active': {
          color: 'var(--blue-500)'
        }
      },
      active: {},
      completed: {}
    }
  }
})

const steps = [
  {
    label: 'Open ProbExpert Bot in your telegram app',
    description: (
      <>
        <span className={Styles.instruction_text}>
          Open your telegram app and search for probexpertbot or{' '}
          <a target="_blank" href="https://t.me/probexpertBot">
            Click here to open the @probExpertbot
          </a>
        </span>
        <img
          src="https://i.imgur.com/ikaBrzZ.gif"
          alt="probexpert bot searching gif"
          className={Styles.instruction_image}
        />
      </>
    )
  },
  {
    label: 'Start the bot and send your username',
    description: (
      <>
        <span className={Styles.instruction_text}>
          Start the bot, and use command /connect to connect your account. Give
          your username to bot, Then go to next step and copy the code, and send
          it using the bot.
        </span>
        <img
          src="https://i.imgur.com/hJDfRlL.gif"
          alt="probexpert bot starting gif"
          // className={Styles.instruction_image}
        />
      </>
    )
  }
]

export default function InstructionStepper() {
  const [activeStep, setActiveStep] = React.useState(0)

  const handleNext = () => {
    setActiveStep((prevActiveStep) => prevActiveStep + 1)
  }

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1)
  }

  const handleReset = () => {
    setActiveStep(0)
  }

  return (
    <Box sx={{ mt: 2 }}>
      <ThemeProvider theme={theme}>
        <Stepper activeStep={activeStep} orientation="vertical">
          {steps.map((step, index) => (
            <Step key={step.label} sx={{ color: 'red' }}>
              <StepLabel
                optional={
                  index === 1 ? (
                    <Typography variant="caption">Last step</Typography>
                  ) : null
                }
              >
                <Typography variant="h6">{step.label}</Typography>
              </StepLabel>
              <StepContent>
                <Typography>{step.description}</Typography>
                <Box sx={{ mb: 2, mt: 1 }}>
                  <div>
                    <Button
                      primary
                      variant="contained"
                      onClick={handleNext}
                      style={{ marginRight: '10px' }}
                    >
                      {index === steps.length - 1 ? 'Finish' : 'Continue'}
                    </Button>

                    {index !== 0 && (
                      <Button
                        secondary
                        disabled={index === 0}
                        onClick={handleBack}
                      >
                        Back
                      </Button>
                    )}
                  </div>
                </Box>
              </StepContent>
            </Step>
          ))}
        </Stepper>
      </ThemeProvider>
      {activeStep === steps.length && (
        <Paper square elevation={0} style={{ padding: '20px' }}>
          <Typography variant="h5">
            Visit next step to find the 6 digit code
          </Typography>
        </Paper>
      )}
    </Box>
  )
}
